@@ -44,7 +44,7 @@
 //
 #define OIIO_VERSION_MAJOR 2
 #define OIIO_VERSION_MINOR 4
-#define OIIO_VERSION_PATCH 5
+#define OIIO_VERSION_PATCH 9
 #define OIIO_VERSION_TWEAK 0
 #define OIIO_VERSION_RELEASE_TYPE 
 
@@ -90,13 +90,13 @@
 
 
 // Establish the name spaces
-namespace OpenImageIO_v2_4_5 { }
-namespace OIIO = OpenImageIO_v2_4_5;
+namespace OpenImageIO_v2_4 { }
+namespace OIIO = OpenImageIO_v2_4;
 
 // Macros to use in each file to enter and exit the right name spaces.
-#define OIIO_NAMESPACE OpenImageIO_v2_4_5
-#define OIIO_NAMESPACE_STRING "OpenImageIO_v2_4_5"
-#define OIIO_NAMESPACE_BEGIN namespace OpenImageIO_v2_4_5 {
+#define OIIO_NAMESPACE OpenImageIO_v2_4
+#define OIIO_NAMESPACE_STRING "OpenImageIO_v2_4"
+#define OIIO_NAMESPACE_BEGIN namespace OpenImageIO_v2_4 {
 #define OIIO_NAMESPACE_END }
 #define OIIO_NAMESPACE_USING using namespace OIIO;
 
